/*
 * HCSR04.h - Library for controlling the HCSR04 distance sensor.
 * Created by Tyler J. Sekosan, March 3, 2019.
 * Released into the public domain. 
 */
 #ifndef HCSR04_h // Checks if the library has been defined in the code already. If it hasn't, then it will define it in the next line. This is to avoid the library from being included twice in your code
 #define HCSR04_h 

 #include "Arduino.h" // includes the basic Arduino commands used to define our own functions

 class HCSR04ProxSensor // a class is a collection of functions and variables kept in one location
 {
  public: // variables and functions within "public" are accessible to any sketches or files that include this library
    HCSR04ProxSensor(int echoPin, int triggerPin); //constructor
    float readSensor(); //Read distance from the sensor in cm 
    float getLastValue(); //get last distance reading to determine if an object is approaching or moving away from the sensor
  private: // "private" will list variables that can only be accessed by functions within this class. Meaning, you would not be able to use them in a sketch that includes this library without going through a function within the library
    int _echoPin; // this will store the pin number used for the echo pin
    int _triggerPin; // this will store the pin number used for the trigger pin
    long _time; // this will store the time it takes for the sound wave to travel from the sensor, to the object, and then back to the sensor
    float _cmDistance; // this stores the object's distance from the sensor
    float _lastValue; // records the distance value that was last calculated before sending another signal
 };

 #endif // ends the #ifndef from earlier
